| Title: | In Vitro Toxicokinetic Data Processed with the 'invitroTKstats' Pipeline |
|---|---|
| Description: | A collection of datasets containing a variety of in vitro toxicokinetic measurements including -- but not limited to -- chemical fraction unbound in the presence of plasma (f_up), intrinsic hepatic clearance (Clint, uL/min/million hepatocytes), and membrane permeability for oral absorption (Caco2). The datasets provided by the package were processed and analyzed with the companion 'invitroTKstats' package. |
| Authors: | Sarah E. Davidson-Fritz [aut] (ORCID: <https://orcid.org/0000-0002-2891-9380>), Caroline Ring [cre] (ORCID: <https://orcid.org/0000-0002-0463-1251>), John Wambaugh [aut] (ORCID: <https://orcid.org/0000-0002-4024-534X>), Lindsay Knupp [ctb], Barbara A. Wetmore [ctb] (ORCID: <https://orcid.org/0000-0002-6878-5348>), Anna Kreutz [ctb] (ORCID: <https://orcid.org/0000-0002-7787-0683>), Marci Smeltz [ctb] (ORCID: <https://orcid.org/0000-0001-9723-8696>), David Crizer [ctb], U.S. Federal Government [cph] (Copyright holder of this package) |
| Maintainer: | Caroline Ring <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.2 |
| Built: | 2026-05-07 09:32:48 UTC |
| Source: | https://github.com/usepa/invitrotkdata |
Mass Spectrometry measurements of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocyte suspensions. Chemicals were per- and polyfluoroalkyl substance (PFAS) samples. The experiments were led by Dr. Crizer.
crizer2024.clintcrizer2024.clint
A level-2 data.frame with 7,070 rows and 24 variables:
Lab.Sample.NameSample description used in the laboratory
DateDate sample was acquired
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of Clint sample
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration – usually the date
ISTD.NameName of compound used as internal standard (ISTD)
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area of internal standard (pixels)
Hep.DensityThe density (units of millions of hepatocytes per mL) hepatocytes in the in vitro incubation
Std.ConcConcentration of analytic standard (for calibration curve) (uM)
Clint.Assay.ConcIntended initial concentration of chemical (uM)
TimeTime when sample was measured (h)
AreaPeak area of analyte (target compound)
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis)
Analysis.ParametersParameters for identifying analyte peak (for example, retention time)
NoteAny laboratory notes about sample
Level0.FileName of data file from laboratory that was used to compile level-0 data.frame
Level0.SheetName of "sheet" (for Excel workbooks) from which the laboratory data were read
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other value causes the data to be ignored.)
Crizer DM, Rice JR, Smeltz MG, Lavrich KS, Ravindra K, Wambaugh JF, DeVito M, Wetmore BA (2024). “In Vitro Hepatic Clearance Evaluations of Per-and Polyfluoroalkyl Substances (PFAS) across Multiple Structural Categories.” Toxics, 12(9), 672.
Frequentist estimates of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocyte suspensions. Chemicals were per- and polyfluoroalkyl substance (PFAS) samples. The experiments were led by Dr. Crizer.
crizer2024.clint.L3crizer2024.clint.L3
A level-3 data.frame with 60 rows and 13 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
CalibrationIdentifier for mass spectrometry calibration – usually the date
ClintFrequentist point estimate for intrinsic hepatic clearance (Clint)
Clint.pValuep-value of the estimated Clint value
FitTest nominal concentrations in the linear regression fit
AICAkaike Information Criterion (AIC) for the linear regression fit
AIC.NullAkaike Information Criterion of the exponential decay assuming a constant rate of decay
Clint.1Intrinsic hepatic clearance at 1 uM (frequentist point estimate)
Clint.10Intrinsic hepatic clearance at 10 uM (frequentist point estimate)
AIC.SatAkaike Information Criterion of the exponential decay with a saturation probability
Sat.pValuep-value of exponential decay with a saturation probability
Crizer DM, Rice JR, Smeltz MG, Lavrich KS, Ravindra K, Wambaugh JF, DeVito M, Wetmore BA (2024). “In Vitro Hepatic Clearance Evaluations of Per-and Polyfluoroalkyl Substances (PFAS) across Multiple Structural Categories.” Toxics, 12(9), 672.
Bayesian estimates of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocyte suspensions. Chemicals were per- and polyfluoroalkyl substance (PFAS) samples. The experiments were led by Dr. Crizer.
crizer2024.clint.L4crizer2024.clint.L4
A level-4 data.frame with 60 rows and 12 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Clint.1.MedPosterior median intrinsic hepatic clearance at 1 uM
Clint.1.LowPosterior 2.5th quantile of intrinsic hepatic clearance at 1 uM (lower credible interval bound)
Clint.1.HighPosterior 97.5th quantile of intrinsic hepatic clearance at 1 uM (upper credible interval bound)
Clint.10.MedPosterior median intrinsic hepatic clearance at 10 uM
Clint.10.LowPosterior 2.5th quantile of intrinsic hepatic clearance at 10 uM (lower credible interval bound)
Clint.10.HighPosterior 97.5th quantile of intrinsic hepatic clearance at 10 uM (upper credible interval bound)
Clint.pValueProbability that a chemical concentration decrease is observed
Sat.pValueProbability that a lower Clint is observed at a higher concentration, i.e. saturation probability
degrades.pValueProbability of abiotic degradation
Crizer DM, Rice JR, Smeltz MG, Lavrich KS, Ravindra K, Wambaugh JF, DeVito M, Wetmore BA (2024). “In Vitro Hepatic Clearance Evaluations of Per-and Polyfluoroalkyl Substances (PFAS) across Multiple Structural Categories.” Toxics, 12(9), 672.
Mass Spectrometry measurements of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocyte suspensions. Chemicals were per- and polyfluoroalkyl substance (PFAS) samples. The experiments were led by Dr.s Anna Kreutz and Barbara Wetmore.
kreutz2023.clintkreutz2023.clint
A level-2 data.frame with 5,800 rows and 25 variables:
Lab.Sample.NameSample description used in the laboratory
DateDate sample was acquired
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of Clint sample
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration – usually the date
Std.ConcConcentration of analytic standard (for calibration curve) (uM)
Clint.Assay.ConcIntended initial concentration of chemical (uM)
TimeTime when sample was measured (h)
ISTD.NameName of compound used as internal standard (ISTD)
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area of internal standard (pixels)
Hep.DensityThe density (units of millions of hepatocytes per mL) hepatocytes in the in vitro incubation
AreaPeak area of analyte (target compound)
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis)
Analysis.ParametersParameters for identifying analyte peak (for example, retention time)
NoteAny laboratory notes about sample
Level0.FileName of data file from laboratory that was used to compile level-0 data.frame
Level0.SheetName of "sheet" (for Excel workbooks) from which the laboratory data were read
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other value causes the data to be ignored.)
Shibata Y, Takahashi H, Chiba M, Ishii Y (2002). “Prediction of hepatic clearance and availability by cryopreserved human hepatocytes: an application of serum incubation method.” Drug Metabolism and disposition, 30(8), 892–896.
Kreutz A, Clifton MS, Henderson WM, Smeltz MG, Phillips M, Wambaugh JF, Wetmore BA (2023). “Category-Based Toxicokinetic Evaluations of Data-Poor Per- and Polyfluoroalkyl Substances (PFAS) using Gas Chromatography Coupled with Mass Spectrometry.” Toxics, 11(5), 463.
Frequentist estimates of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocyte suspensions. Chemicals were per- and polyfluoroalkyl substance (PFAS) samples. The experiments were led by Dr.s Anna Kreutz and Barbara Wetmore.
kreutz2023.clint.L3kreutz2023.clint.L3
A level-3 data.frame with 25 rows and 13 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
CalibrationIdentifier for mass spectrometry calibration – usually the date
ClintFrequentist point estimate for intrinsic hepatic clearance (Clint)
Clint.pValuep-value of the estimated Clint value
FitTest nominal concentrations in the linear regression fit
AICAkaike Information Criterion (AIC) for the linear regression fit
AIC.NullAkaike Information Criterion of the exponential decay assuming a constant rate of decay
Clint.1Intrinsic hepatic clearance at 1 uM (frequentist point estimate)
Clint.10Intrinsic hepatic clearance at 10 uM (frequentist point estimate)
AIC.SatAkaike Information Criterion of the exponential decay with a saturation probability
Sat.pValuep-value of exponential decay with a saturation probability
Shibata Y, Takahashi H, Chiba M, Ishii Y (2002). “Prediction of hepatic clearance and availability by cryopreserved human hepatocytes: an application of serum incubation method.” Drug Metabolism and disposition, 30(8), 892–896.
Kreutz A, Clifton MS, Henderson WM, Smeltz MG, Phillips M, Wambaugh JF, Wetmore BA (2023). “Category-Based Toxicokinetic Evaluations of Data-Poor Per- and Polyfluoroalkyl Substances (PFAS) using Gas Chromatography Coupled with Mass Spectrometry.” Toxics, 11(5), 463.
Bayesian estimates of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocyte suspensions. Chemicals were per- and polyfluoroalkyl substance (PFAS) samples. The experiments were led by Dr.s Anna Kreutz and Barbara Wetmore.
kreutz2023.clint.L4kreutz2023.clint.L4
A level-4 data.frame with 25 rows and 12 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Clint.1.MedPosterior median intrinsic hepatic clearance at 1 uM
Clint.1.LowPosterior 2.5th quantile of intrinsic hepatic clearance at 1 uM (lower credible interval bound)
Clint.1.HighPosterior 97.5th quantile of intrinsic hepatic clearance at 1 uM (upper credible interval bound)
Clint.10.MedPosterior median intrinsic hepatic clearance at 10 uM
Clint.10.LowPosterior 2.5th quantile of intrinsic hepatic clearance at 10 uM (lower credible interval bound)
Clint.10.HighPosterior 97.5th quantile of intrinsic hepatic clearance at 10 uM (upper credible interval bound)
Clint.pValueProbability that a chemical concentration decrease is observed
Sat.pValueProbability that a lower Clint is observed at a higher concentration, i.e. saturation probability
degrades.pValueProbability of abiotic degradation
Shibata Y, Takahashi H, Chiba M, Ishii Y (2002). “Prediction of hepatic clearance and availability by cryopreserved human hepatocytes: an application of serum incubation method.” Drug Metabolism and disposition, 30(8), 892–896.
Kreutz A, Clifton MS, Henderson WM, Smeltz MG, Phillips M, Wambaugh JF, Wetmore BA (2023). “Category-Based Toxicokinetic Evaluations of Data-Poor Per- and Polyfluoroalkyl Substances (PFAS) using Gas Chromatography Coupled with Mass Spectrometry.” Toxics, 11(5), 463.
Mass Spectrometry measurements of plasma protein binding measured by ultracentrifugation (UC) for per- and poly-fluorinated alkyl substance (PFAS) samples from experiments led by Dr.s Anna Kreutz and Barbara Wetmore.
kreutz2023.uckreutz2023.uc
A level-2 data.frame with 2,955 rows and 23 variables:
Lab.Sample.NameSample description used in the laboratory
DateDate sample was acquired
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of UC sample
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration – usually the date
Standard.ConcConcentration of analytic standard (for calibration curve) (uM)
UC.Assay.T1.ConcIntended concentration of chemical intended in T1 sample (uM)
ISTD.NameName of compound used as internal standard (ISTD)
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area of internal standard (pixels)
SeriesIdentier for replicate series of UC measurements
AreaPeak area of analyte (target compound)
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis
Analysis.ParametersParameters for identifying analyte peak (for example, retention time)
NoteAny laboratory notes about sample
Level0.FileName of data file from laboratory that was used to compile level-0 data.frame
Level0.SheetName of "sheet" (for Excel workbooks) from which the laboratory data were read
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other value causes the data to be ignored.)
Howard ML, Hill JJ, Galluppi GR, McLean MA (2010). “Plasma protein binding in drug discovery and development.” Combinatorial chemistry & high throughput screening, 13(2), 170–187.
Kreutz A, Clifton MS, Henderson WM, Smeltz MG, Phillips M, Wambaugh JF, Wetmore BA (2023). “Category-Based Toxicokinetic Evaluations of Data-Poor Per- and Polyfluoroalkyl Substances (PFAS) using Gas Chromatography Coupled with Mass Spectrometry.” Toxics, 11(5), 463.
Frequentist estimates of plasma protein binding measured by ultracentrifugation (UC) for per- and poly-fluorinated alkyl substance (PFAS) samples from experiments led by Dr.s Anna Kreutz and Barbara Wetmore.
kreutz2023.uc.L3kreutz2023.uc.L3
A level-3 data.frame with 73 rows and 5 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
CalibrationIdentifier for mass spectrometry calibration – usually the date
FupFrequentist point estimate for fraction unbound in plasma (fup)
Howard ML, Hill JJ, Galluppi GR, McLean MA (2010). “Plasma protein binding in drug discovery and development.” Combinatorial chemistry & high throughput screening, 13(2), 170–187.
Kreutz A, Clifton MS, Henderson WM, Smeltz MG, Phillips M, Wambaugh JF, Wetmore BA (2023). “Category-Based Toxicokinetic Evaluations of Data-Poor Per- and Polyfluoroalkyl Substances (PFAS) using Gas Chromatography Coupled with Mass Spectrometry.” Toxics, 11(5), 463.
Bayesian estimates of plasma protein binding measured by ultracentrifugation (UC) for per- and poly-fluorinated alkyl substance (PFAS) samples from experiments led by Dr.s Anna Kreutz and Barbara Wetmore.
kreutz2023.uc.L4kreutz2023.uc.L4
A level-4 data.frame with 52 rows and 13 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Fstable.MedPosterior median chemical stability fraction
Fstable.LowPosterior 2.5th quantile chemical stability fraction (lower credible interval bound)
Fstable.HighPosterior 97.5th quantile chemical stability fraction (upper credible interval bound)
Fup.MedPosterior median fraction unbound in plasma
Fup.LowPosterior 2.5th quantile of fraction unbound in plasma (lower credible interval bound)
Fup.HighPosterior 97.5th quantile of fraction unbound in plasma (upper credible interval bound)
Fup.pointPoint estimate of fraction unbound in plasma
UnstableQualitative determination of chemical stability. "Y" indicates observed chemical stability.
UncertainQualitative determination of uncertainty about chemical stability. "Y" indicates uncertainty in observed chemical stability.
CVCoefficient of variance
Howard ML, Hill JJ, Galluppi GR, McLean MA (2010). “Plasma protein binding in drug discovery and development.” Combinatorial chemistry & high throughput screening, 13(2), 170–187.
Kreutz A, Clifton MS, Henderson WM, Smeltz MG, Phillips M, Wambaugh JF, Wetmore BA (2023). “Category-Based Toxicokinetic Evaluations of Data-Poor Per- and Polyfluoroalkyl Substances (PFAS) using Gas Chromatography Coupled with Mass Spectrometry.” Toxics, 11(5), 463.
Mass Spectrometry measurements of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocytes. Chemicals were per- and polyfluoroalkyl substance (PFAS) samples. The experiments were led by Dr.s Marci Smeltz and Barbara Wetmore.
smeltz2023.clintsmeltz2023.clint
A level-2 data.frame with 625 rows and 24 variables:
Lab.Sample.NameSample description used in the laboratory
DateDate sample was acquired
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of Clint sample
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration – usually the date
Std.ConcConcentration of analytic standard (for calibration curve) (uM)
Clint.Assay.ConcIntended initial concentration of chemical (uM)
TimeTime when sample was measured (h)
ISTD.NameName of compound used as internal standard (ISTD)
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area of internal standard (pixels)
Hep.DensityThe density (units of millions of hepatocytes per mL) hepatocytes in the in vitro incubation
AreaPeak area of analyte (target compound)
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis
Analysis.ParametersParameters for identifying analyte peak (for example, retention time)
NoteAny laboratory notes about sample
Level0.FileName of data file from laboratory that was used to compile level0 data table)
Level0.SheetName of "sheet" (for Excel workbooks) from which the laboratory data were read
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other value causes the data to be ignored.)
Shibata Y, Takahashi H, Chiba M, Ishii Y (2002). “Prediction of hepatic clearance and availability by cryopreserved human hepatocytes: an application of serum incubation method.” Drug Metabolism and disposition, 30(8), 892–896.
Smeltz M, Wambaugh JF, Wetmore BA (2023). “Plasma Protein Binding Evaluations of Per- and Polyfluoroalkyl Substances for Category-Based Toxicokinetic Assessment.” Chemical Research in Toxicology, 36(6), 870–881.
Frequentist estimate of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocytes. Chemicals were per- and polyfluoroalkyl substance (PFAS) samples. The experiments were led by Dr.s Marci Smeltz and Barbara Wetmore.
smeltz2023.clint.L3smeltz2023.clint.L3
A level-3 data.frame with 6 rows and 13 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
CalibrationIdentifier for mass spectrometry calibration – usually the date
ClintFrequentist point estimate for intrinsic hepatic clearance (Clint)
Clint.pValuep-value of the estimated Clint value
FitTest nominal concentrations in the linear regression fit
AICAkaike Information Criterion (AIC) for the linear regression fit
AIC.NullAkaike Information Criterion of the exponential decay assuming a constant rate of decay
Clint.1Intrinsic hepatic clearance at 1 uM (frequentist point estimate)
Clint.10Intrinsic hepatic clearance at 10 uM (frequentist point estimate)
AIC.SatAkaike Information Criterion of the exponential decay with a saturation probability
Sat.pValuep-value of exponential decay with a saturation probability
Shibata Y, Takahashi H, Chiba M, Ishii Y (2002). “Prediction of hepatic clearance and availability by cryopreserved human hepatocytes: an application of serum incubation method.” Drug Metabolism and disposition, 30(8), 892–896.
Smeltz M, Wambaugh JF, Wetmore BA (2023). “Plasma Protein Binding Evaluations of Per- and Polyfluoroalkyl Substances for Category-Based Toxicokinetic Assessment.” Chemical Research in Toxicology, 36(6), 870–881.
Bayesian estimate of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocytes. Chemicals were per- and polyfluoroalkyl substance (PFAS) samples. The experiments were led by Dr.s Marci Smeltz and Barbara Wetmore.
smeltz2023.clint.L4smeltz2023.clint.L4
A level-4 data.frame with 7 rows and 12 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Clint.1.MedPosterior median intrinsic hepatic clearance at 1 uM
Clint.1.LowPosterior 2.5th quantile of intrinsic hepatic clearance at 1 uM (lower credible interval bound)
Clint.1.HighPosterior 97.5th quantile of intrinsic hepatic clearance at 1 uM (upper credible interval bound)
Clint.10.MedPosterior median intrinsic hepatic clearance at 10 uM
Clint.10.LowPosterior 2.5th quantile of intrinsic hepatic clearance at 10 uM (lower credible interval bound)
Clint.10.HighPosterior 97.5th quantile of intrinsic hepatic clearance at 10 uM (upper credible interval bound)
Clint.pValueProbability that a chemical concentration decrease is observed
Sat.pValueProbability that a lower Clint is observed at a higher concentration, i.e. saturation probability
degrades.pValueProbability of abiotic degradation
Shibata Y, Takahashi H, Chiba M, Ishii Y (2002). “Prediction of hepatic clearance and availability by cryopreserved human hepatocytes: an application of serum incubation method.” Drug Metabolism and disposition, 30(8), 892–896.
Smeltz M, Wambaugh JF, Wetmore BA (2023). “Plasma Protein Binding Evaluations of Per- and Polyfluoroalkyl Substances for Category-Based Toxicokinetic Assessment.” Chemical Research in Toxicology, 36(6), 870–881.
Mass Spectrometry measurements of plasma protein binding measured by rapid equilibrium dialysis (RED) for per- and poly-fluorinated alkyl substance (PFAS) samples from experiments led by Dr.s Marci Smeltz and Barbara Wetmore.
smeltz2023.redsmeltz2023.red
A level-2 data.frame with 3,955 rows and 25 variables:
Lab.Sample.NameSample description used in the laboratory
DateDate sample was acquired
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of RED sample
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration – usually the date
Std.ConcConcentration of analytic standard (for calibration curve) (uM)
Test.Nominal.ConcIntended concentration of chemical introduced into RED plate (uM)
Percent.Physiologic.PlasmaPercent of physiological plasma concentration in RED plate (in percent)
TimeTime of sample measurement (h)
ISTD.NameName of compound used as internal standard (ISTD)
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area of internal standard (pixels)
ReplicateIdentifier for replicate series of RED measurements
AreaPeak area of analyte (target compound)
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis
Analysis.ParametersParameters for identifying analyte peak (for example, retention time)
NoteAny laboratory notes about sample
Level0.FileName of data file from laboratory that was used to compile level-0 data.frame
Level0.SheetName of "sheet" (for Excel workbooks) from which the laboratory data were read
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other value causes the data to be ignored.)
Waters NJ, Jones R, Williams G, Sohal B (2008). “Validation of a rapid equilibrium dialysis approach for the measurement of plasma protein binding.” Journal of pharmaceutical sciences, 97(10), 4586–4595.
Smeltz M, Wambaugh JF, Wetmore BA (2023). “Plasma Protein Binding Evaluations of Per- and Polyfluoroalkyl Substances for Category-Based Toxicokinetic Assessment.” Chemical Research in Toxicology, 36(6), 870–881.
Frequentist estimate of plasma protein binding measured by rapid equilibrium dialysis (RED) for per- and poly-fluorinated alkyl substance (PFAS) samples from experiments led by Dr.s Marci Smeltz and Barbara Wetmore.
smeltz2023.red.L3smeltz2023.red.L3
A level-3 data.frame with 15 rows and 4 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
CalibrationIdentifier for mass spectrometry calibration – usually the date
FupFrequentist point estimate for fraction unbound in plasma (fup)
Waters NJ, Jones R, Williams G, Sohal B (2008). “Validation of a rapid equilibrium dialysis approach for the measurement of plasma protein binding.” Journal of pharmaceutical sciences, 97(10), 4586–4595.
Smeltz M, Wambaugh JF, Wetmore BA (2023). “Plasma Protein Binding Evaluations of Per- and Polyfluoroalkyl Substances for Category-Based Toxicokinetic Assessment.” Chemical Research in Toxicology, 36(6), 870–881.
Bayesian estimate of plasma protein binding measured by rapid equilibrium dialysis (RED) for per- and poly-fluorinated alkyl substance (PFAS) samples from experiments led by Dr.s Marci Smeltz and Barbara Wetmore.
smeltz2023.red.L4smeltz2023.red.L4
A level-4 data.frame with 15 rows and 7 variables:
Compound.NameCompound name
Lab.Compound.NameCompound as described in the laboratory
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Fup.pointPoint estimate of fraction unbound in plasma
Fup.MedPosterior median estimate of fraction unbound in plasma
Fup.LowPosterior 2.5th quantile of fraction unbound in plasma (lower credible interval bound)
Fup.HighPosterior 97.5th quantile of fraction unbound in plasma (upper credible interval bound)
Waters NJ, Jones R, Williams G, Sohal B (2008). “Validation of a rapid equilibrium dialysis approach for the measurement of plasma protein binding.” Journal of pharmaceutical sciences, 97(10), 4586–4595.
Smeltz M, Wambaugh JF, Wetmore BA (2023). “Plasma Protein Binding Evaluations of Per- and Polyfluoroalkyl Substances for Category-Based Toxicokinetic Assessment.” Chemical Research in Toxicology, 36(6), 870–881.
Mass Spectrometry measurements of plasma protein binding measured by ultracentrifugation (UC) for per- and poly-fluorinated alkyl substance (PFAS) samples from experiments led by Dr.s Marci Smeltz and Barbara Wetmore.
smeltz2023.ucsmeltz2023.uc
A level-2 data.frame with 10,133 rows and 23 variables:
Lab.Sample.NameSample description used in the laboratory
DateDate sample was acquired
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of UC sample
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration – usually the date
Standard.ConcConcentration of analytic standard (for calibration curve) (uM)
UC.Assay.T1.ConcIntended concentration of chemical in T1 sample (uM)
ISTD.NameName of compound used as internal standard (ISTD)
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area of internal standard (pixels)
SeriesIdentifier for replicate series of UC measurements
AreaPeak area of analyte (target compound)
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis
Analysis.ParametersParameters for identifying analyte peak (for example, retention time)
NoteAny laboratory notes about sample
Level0.FileName of data file from laboratory that was used to compile level-0 data.frame
Level0.SheetName of "sheet" (for Excel workbooks) from which the laboratory data were read
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other value causes the data to be ignored.)
Howard ML, Hill JJ, Galluppi GR, McLean MA (2010). “Plasma protein binding in drug discovery and development.” Combinatorial chemistry & high throughput screening, 13(2), 170–187.
Smeltz M, Wambaugh JF, Wetmore BA (2023). “Plasma Protein Binding Evaluations of Per- and Polyfluoroalkyl Substances for Category-Based Toxicokinetic Assessment.” Chemical Research in Toxicology, 36(6), 870–881.
Frequentist estimate of plasma protein binding measured by ultracentrifugation (UC) for per- and poly-fluorinated alkyl substance (PFAS) samples from experiments led by Dr.s Marci Smeltz and Barbara Wetmore.
smeltz2023.uc.L3smeltz2023.uc.L3
A level-3 data.frame with 107 rows and 5 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
CalibrationIdentifier for mass spectrometry calibration – usually the date
FupFrequentist point estimate for fraction unbound in plasma (fup)
Howard ML, Hill JJ, Galluppi GR, McLean MA (2010). “Plasma protein binding in drug discovery and development.” Combinatorial chemistry & high throughput screening, 13(2), 170–187.
Smeltz M, Wambaugh JF, Wetmore BA (2023). “Plasma Protein Binding Evaluations of Per- and Polyfluoroalkyl Substances for Category-Based Toxicokinetic Assessment.” Chemical Research in Toxicology, 36(6), 870–881.
Bayesian estimate of plasma protein binding measured by ultracentrifugation (UC) for per- and poly-fluorinated alkyl substance (PFAS) samples from experiments led by Dr.s Marci Smeltz and Barbara Wetmore.
smeltz2023.uc.L4smeltz2023.uc.L4
A level-4 data.frame with 69 rows and 7 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Fup.MedPosterior median fraction unbound in plasma
Fup.LowPosterior 2.5th quantile of fraction unbound in plasma (lower credible interval bound)
Fup.HighPosterior 97.5th quantile of fraction unbound in plasma (upper credible interval bound)
Fup.pointPoint estimate of fraction unbound in plasma
Howard ML, Hill JJ, Galluppi GR, McLean MA (2010). “Plasma protein binding in drug discovery and development.” Combinatorial chemistry & high throughput screening, 13(2), 170–187.
Smeltz M, Wambaugh JF, Wetmore BA (2023). “Plasma Protein Binding Evaluations of Per- and Polyfluoroalkyl Substances for Category-Based Toxicokinetic Assessment.” Chemical Research in Toxicology, 36(6), 870–881.
Mass spectrometry measurements of intrinsic hepatic clearance (Clint) measured using in vitro suspensions of pooled primary human hepatocytes (Shibata et al. 2002).
wambaugh2019.clintwambaugh2019.clint
A data.frame with 22898 rows and 26 variables:
Lab.Sample.NameSample description used in the laboratory
DateDate sample was acquired
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of Clint sample
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration – usually the date
ISTD.NameName of compound used as internal standard (ISTD)
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area of internal standard (pixels)
AreaPeak area of analyte (target compound)
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis
Analysis.ParametersParameters for identifying analyte peak (for example, retention time)
NoteAny laboratory notes about sample
Level0.FileName of data file from laboratory that was used to compile level-0 data.frame
Level0.SheetName of "sheet" (for Excel workbooks) from which the laboratory data were read
TimeTime when sample was measured (h)
Test.Compound.ConcMeasured concentration of analytic standard (for calibration curve) (uM)
Test.Nominal.ConcExpected initial concentration of chemical added to donor side (uM)
Hep.DensityThe density (units of millions of hepatocytes per mL) hepatocytes in the in vitro incubation
Biological.ReplicatesIdentifier for measurements of multiple samples with the same analyte
Technical.ReplicatesIdentifier for measurements of one sample of a compound
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other value causes the data to be ignored.)
Wambaugh et al. (2019)
Shibata Y, Takahashi H, Chiba M, Ishii Y (2002). “Prediction of hepatic clearance and availability by cryopreserved human hepatocytes: an application of serum incubation method.” Drug Metabolism and disposition, 30(8), 892–896.
Wambaugh JF, Wetmore BA, Ring CL, Nicolas CI, Pearce RG, Honda GS, Dinallo R, Angus D, Gilbert J, Sierra T, others (2019). “Assessing toxicokinetic uncertainty and variability in risk prioritization.” Toxicological Sciences, 172(2), 235–251.
Frequentist estimate of intrinsic hepatic clearance (Clint) measured using in vitro suspensions of pooled primary human hepatocytes (Shibata et al. 2002).
wambaugh2019.clint.L3wambaugh2019.clint.L3
A data.frame with 473 rows and 13 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemical Dashboard)
Lab.Compound.NameCompound as described in the laboratory
CalibrationIdentifier for mass spectrometry calibration - usually the date
ClintFrequentist point estimate for intrinsic hepatic clearance (Clint)
Clint.pValuep-value of the estimated Clint value
FitTest nominal concentrations in the linear regression fit
AICAkaike Information Criterion (AIC) for the linear regression fit
AIC.NullAkaike Information Criterion of the exponential decay assuming a constant rate of decay
Clint.1Intrinsic hepatic clearance at 1 uM (frequentist point estimate)
Clint.10Intrinsic hepatic clearance at 10 uM (frequentist point estimate)
AIC.SatAkaike Information Criterion of the exponential decay with a saturation probability
Sat.pValuep-value of exponential decay with a saturation probability
Wambaugh et al. (2019)
Shibata Y, Takahashi H, Chiba M, Ishii Y (2002). “Prediction of hepatic clearance and availability by cryopreserved human hepatocytes: an application of serum incubation method.” Drug Metabolism and disposition, 30(8), 892–896.
Wambaugh JF, Wetmore BA, Ring CL, Nicolas CI, Pearce RG, Honda GS, Dinallo R, Angus D, Gilbert J, Sierra T, others (2019). “Assessing toxicokinetic uncertainty and variability in risk prioritization.” Toxicological Sciences, 172(2), 235–251.
Bayesian estimate of intrinsic hepatic clearance (Clint) measured using in vitro suspensions of pooled primary human hepatocytes (Shibata et al. 2002).
wambaugh2019.clint.L4wambaugh2019.clint.L4
A level-4 data.frame with 473 rows and 12 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Clint.1.MedPosterior median intrinsic hepatic clearance at 1 uM
Clint.1.LowPosterior 2.5th quantile of intrinsic hepatic clearance at 1 uM (lower credible interval bound)
Clint.1.HighPosterior 97.5th quantile of intrinsic hepatic clearance at 1 uM (upper credible interval bound)
Clint.10.MedPosterior median intrinsic hepatic clearance at 10 uM
Clint.10.LowPosterior 2.5th quantile of intrinsic hepatic clearance at 10 uM (lower credible interval bound)
Clint.10.HighPosterior 97.5th quantile of intrinsic hepatic clearance at 10 uM (upper credible interval bound)
Clint.pValueProbability that a chemical concentration decrease is observed
Sat.pValueProbability that a lower Clint is observed at a higher concentration, i.e. saturation probability
degrades.pValueProbability of abiotic degradation
Wambaugh et al. (2019)
Shibata Y, Takahashi H, Chiba M, Ishii Y (2002). “Prediction of hepatic clearance and availability by cryopreserved human hepatocytes: an application of serum incubation method.” Drug Metabolism and disposition, 30(8), 892–896.
Wambaugh JF, Wetmore BA, Ring CL, Nicolas CI, Pearce RG, Honda GS, Dinallo R, Angus D, Gilbert J, Sierra T, others (2019). “Assessing toxicokinetic uncertainty and variability in risk prioritization.” Toxicological Sciences, 172(2), 235–251.
Mass spectrometry measurements of plasma protein binding using the rapid equilibrium dialysis (RED) assay method (Waters et al. 2008).
wambaugh2019.redwambaugh2019.red
A data.frame 15990 rows and 26 variables:
Lab.Sample.NameSample description used in the laboratory
DateDate sample was acquired
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of RED sample
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration - usually the date
ISTD.NameName of compound used as internal standard (ISTD)
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area internal standard (pixels)
AreaPeak area of analyte (target compound)
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis
Analysis.ParametersParameters for identifying analyte peak (for example, retention time)
NoteAny laboratory notes about sample
Level0.FileName of data file from laboratory that was used to compile level-0 data.frame
Level0.SheetName of "sheet" (for Excel workbooks) from which the laboratory data were read
TimeTime when sample was measured (h)
Test.Compound.ConcMeasured concentration of analytic standard (for calibration curve) (uM)
Test.Nominal.ConcExpected initial concentration of chemical added to donor side (uM)
Percent.Physiologic.PlasmaPercent of physiology plasma concentration in RED plate (in percent)
Biological.ReplicatesIdentifier for measurements of multiple samples with the same analyte
Technical.ReplicatesIdentifier for measurements of one sample of a compound
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other value causes the data to be ignored.)
Wambaugh et al. (2019)
Waters NJ, Jones R, Williams G, Sohal B (2008). “Validation of a rapid equilibrium dialysis approach for the measurement of plasma protein binding.” Journal of pharmaceutical sciences, 97(10), 4586–4595.
Wambaugh JF, Wetmore BA, Ring CL, Nicolas CI, Pearce RG, Honda GS, Dinallo R, Angus D, Gilbert J, Sierra T, others (2019). “Assessing toxicokinetic uncertainty and variability in risk prioritization.” Toxicological Sciences, 172(2), 235–251.
Frequentist estimate of plasma protein binding using the rapid equilibrium dialysis (RED) assay method (Waters et al. 2008).
wambaugh2019.red.L3wambaugh2019.red.L3
A data.frame 368 rows and 4 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
CalibrationIdentifier for mass spectrometry calibration - usually the date
FupFrequentist point estimate for fraction unbound in plasma (fup)
Wambaugh et al. (2019)
Waters NJ, Jones R, Williams G, Sohal B (2008). “Validation of a rapid equilibrium dialysis approach for the measurement of plasma protein binding.” Journal of pharmaceutical sciences, 97(10), 4586–4595.
Wambaugh JF, Wetmore BA, Ring CL, Nicolas CI, Pearce RG, Honda GS, Dinallo R, Angus D, Gilbert J, Sierra T, others (2019). “Assessing toxicokinetic uncertainty and variability in risk prioritization.” Toxicological Sciences, 172(2), 235–251.
Bayesian estimate of plasma protein binding using the rapid equilibrium dialysis (RED) assay method (Waters et al. 2008).
wambaugh2019.red.L4wambaugh2019.red.L4
A data.frame 301 rows and 7 variables:
Compound.NameCompound name
Lab.Compound.NameCompound as described in the laboratory
DTXSIDDSSTox Substance Identifier (CompTox Chemical Dashboard)
Fup.pointPoint estimate of fraction unbound in plasma
Fup.MedPosterior median fraction unbound in plasma
Fup.LowPosterior 2.5th quantile of fraction unbound in plasma (lower credible interval bound)
Fup.HighPosterior 97.5th quantile of fraction unbound in plasma (upper credible interval bound)
Wambaugh et al. (2019)
Waters NJ, Jones R, Williams G, Sohal B (2008). “Validation of a rapid equilibrium dialysis approach for the measurement of plasma protein binding.” Journal of pharmaceutical sciences, 97(10), 4586–4595.
Wambaugh JF, Wetmore BA, Ring CL, Nicolas CI, Pearce RG, Honda GS, Dinallo R, Angus D, Gilbert J, Sierra T, others (2019). “Assessing toxicokinetic uncertainty and variability in risk prioritization.” Toxicological Sciences, 172(2), 235–251.